==> nfe-4.50.5.tar.gz: nfe-4.50.5/nfe/nfce/consrecinfce.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2017 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2017, Creative Commons
Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from nfe.nfe_400.manual_600.consrecinfe import ProcNFe, ABERTURA
from nfe.pysped.xml_sped import tira_abertura
from nfe.nfce.nfce import NFCe
from nfe.nfce.cancnfce_400 import RetCancNFe
from nfe.nfe_400.manual_600.consrecinfe import ProtNFe
from nfe.nfe_400.manual_600 import conssitnfe as conssitnfe_600



class ProcNFCe(ProcNFe):
    def __init__(self):
        super(ProcNFCe, self).__init__()
        self.NFe = NFCe()

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.NFe.xml.replace(ABERTURA, u'')
        xml += self.protNFe.xml.replace(ABERTURA, u'')
        if self.cancNfe.xml:
            xml += self.cancNfe.xml.replace(ABERTURA, u'')

        xml += u'</nfeProc>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.NFe.xml = arquivo
            self.protNFe.xml = arquivo
            self.cancNfe.xml = arquivo

class RetConsSitNFe(conssitnfe_600.RetConsSitNFe):
    def __init__(self):
        super(RetConsSitNFe, self).__init__()

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.cUF.xml
        xml += self.chNFe.xml
        if self.protNFe is not None:
            xml += self.protNFe.xml
        if self.retCancNFe is not None:
            xml += tira_abertura(self.retCancNFe.xml)
        for p in self.procEventoNFe:
            xml += p.xml
        xml += u'</retConsSitNFe>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.cUF.xml = arquivo
            self.dhRecbto.xml = arquivo
            self.chNFe.xml = arquivo
            if self._le_noh(u'//retConsSitNFe/protNFe'):
                self.protNFe = ProtNFe()
                self.protNFe.xml = arquivo
            if self._le_noh(u'//retConsSitNFe/retCancNFe'):
                self.retCancNFe = RetCancNFe()
                self.retCancNFe.xml = arquivo

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> nfe-4.50.8.tar.gz: nfe-4.50.8/nfe/nfce/consrecinfce.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2017 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2017, Creative Commons
Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from nfe.nfe_400.manual_600.consrecinfe import ProcNFe, ABERTURA
from nfe.pysped.xml_sped import tira_abertura
from nfe.nfce.nfce import NFCe
from nfe.nfce.cancnfce_400 import RetCancNFe
from nfe.nfe_400.manual_600.consrecinfe import ProtNFe
from nfe.nfe_400.manual_600 import conssitnfe as conssitnfe_600



class ProcNFCe(ProcNFe):
    def __init__(self):
        super(ProcNFCe, self).__init__()
        self.NFe = NFCe()

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.NFe.xml.replace(ABERTURA, u'')
        xml += self.protNFe.xml.replace(ABERTURA, u'')
        if self.cancNfe.xml and self.cancNfe.infCanc.cStat.valor:
            xml += self.cancNfe.xml.replace(ABERTURA, u'')

        xml += u'</nfeProc>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.NFe.xml = arquivo
            self.protNFe.xml = arquivo
            self.cancNfe.xml = arquivo

class RetConsSitNFe(conssitnfe_600.RetConsSitNFe):
    def __init__(self):
        super(RetConsSitNFe, self).__init__()

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.cUF.xml
        xml += self.chNFe.xml
        if self.protNFe is not None:
            xml += self.protNFe.xml
        if self.retCancNFe is not None:
            xml += tira_abertura(self.retCancNFe.xml)
        for p in self.procEventoNFe:
            xml += p.xml
        xml += u'</retConsSitNFe>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.cUF.xml = arquivo
            self.dhRecbto.xml = arquivo
            self.chNFe.xml = arquivo
            if self._le_noh(u'//retConsSitNFe/protNFe'):
                self.protNFe = ProtNFe()
                self.protNFe.xml = arquivo
            if self._le_noh(u'//retConsSitNFe/retCancNFe'):
                self.retCancNFe = RetCancNFe()
                self.retCancNFe.xml = arquivo

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
